
<div class="container-fluid  dashboard-content">
    <!-- ============================================================== -->
    <!-- reset password form -->
    <!-- ============================================================== -->
    <div class="col-12 col-lg-8 col-xl-6">
        <div class="card">
            <h3 class="card-header">Reset Password </h3>
            <div class="card-body">

                <form id="reset-password-form" data-parsley-validate="" novalidate="" action="{{ url_for('reset_password_request') }}" method="post">

                    {% with messages = get_flashed_messages() %}
                      {% if messages %}
                        {% for message in messages %}
                            {% set alert_type = 'danger' if message.startswith('ERROR') else 'info' %}
                            <div class="alert alert-{{ alert_type }}" role="alert">
                                {{ message }}
                            </div>
                        {% endfor %}
                      {% endif %}
                    {% endwith %}

                    <div class="form-group row">
                        <label class="col-12 col-sm-3 col-form-label text-sm-right">User email</label>
                        <div class="col-8 col-sm-6">
                            <input type="text"  name="user-email" required="true" placeholder="Enter your email" class="form-control">
                        </div>
                    </div>

                    <div class="form-group row">
                        <label class="col-12 col-sm-3 col-form-label text-sm-right"></label>
                        <div class="col-8 col-sm-6">
                            <div class="row">
                                <div class="col col-sm-12 col-lg-12 offset-sm-1 offset-lg-0 text-right">
                                    <button type="submit" class="btn btn-space btn-danger">Reset Password</button>
                                </div>
                            </div>
                        </div>
                    </div>

                </form>
            </div>
        </div>
    </div>
    <!-- ============================================================== -->
    <!-- end of reset password form -->
    <!-- ============================================================== -->

</div>

