
{% set N = 2 + images|length %}

{% import "entry_macros.html" as macros %}

{% set table = [] %}
{% for row in data['grids_storage_table'] %}
    {% do table.append([row['gridbox_label'], row['sample'], row['comments']])  %}
{% endfor %}


{% include "report_header.html" %}

{{ macros.header_card(entry_type['label'], entry.date, (2, N)) }}
{{ macros.table_card('Grids Comments ', table) }}

{% for row in images %}
    {{ macros.header_card(entry_type['label'], entry.date, (3 + loop.index0, N)) }}
    {{ macros.image_card(row['image_title'], row['image_data']) }}
{% endfor %}













