
<div class="container-fluid dashboard-content">
    <div class="row">
        <div class="col-xl-12 col-lg-12 col-md-12 col-sm-12 col-12">
            <div class="page-header">
                <h2 class="pageheader-title">Welcome</h2>
                <!-- <p class="pageheader-text">Nulla euismod urna eros, sit amet scelerisque torton lectus vel mauris facilisis faucibus at enim quis massa lobortis rutrum.</p> -->
                <div class="page-breadcrumb">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item"><a href="#" class="breadcrumb-link">Testing</a></li>
                            <li class="breadcrumb-item active" aria-current="page">Welcome</li>
                        </ol>
                    </nav>
                </div>
            </div>
        </div>
    </div>
    <h1>Welcome to the CryoEM facility portal</h1>
</div>


