@charset "UTF-8";

#imageUpload
{
    display: none;
}

#profileImage
{
    cursor: pointer;
}

#profile-container {
    width: 150px;
    height: 150px;
    overflow: hidden;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    -ms-border-radius: 50%;
    -o-border-radius: 50%;
    border-radius: 50%;
}

#profile-container img {
    width: 150px;
    height: 150px;
}

/* unvisited link */
.page-content a:link {
  color: #4c979f;
}

/* visited link */
.page-content a:visited {
  color: #4c979f;
}

/* mouse over link */
.page-content a:hover {
  color: #a7c947;
}

/* selected link */
a:active {
  color: #a7c947;
}

/* Custom, iPhone Retina */
@media only screen and (max-width:320px) {}