

{% for param in params  %}
    {% set param_id = param['id'] if 'id' in param else loop.index %}
    {% set param_name = param_id %}
    {% set data_key = ' data-key=%s '|format(param_id) %}
    {% set id_name = 'id=%s name=%s'|format(param_id, param_name) %}
    {% set type = param.get('type', 'string') %}
    {% set help = param.get('help', '') %}
    {% set value = param['value'] %}

    <div class="form-group row">

        {% if type == 'table' %}
            <div class="col-12">
                {% set table = param %}
                {% include 'dynamic_table.html' %}
            </div>

        {% else %}
            <label class="col-12 col-sm-3 text-sm-right">{{ param['label'] }} </label>
            <div class="col-12 col-sm-9 col-lg-6">
                {% set selectpicker = True %}
                {% include "dynamic_param.html" %}
            </div>
        {% endif %}
    </div>

{% endfor %}
