
<div class="container-fluid  dashboard-content">
    <!-- ============================================================== -->
    <!-- login form -->
    <!-- ============================================================== -->
    <div class="col-12 col-lg-8 col-xl-6">
        <div class="card">
            <h3 class="card-header">User login</h3>
            <div class="card-body">

                <form id="login-form" data-parsley-validate="" novalidate="" action="{{ url_for('do_login') }}" method="post">

                    {% with messages = get_flashed_messages() %}
                      {% if messages %}
                            {% for message in messages %}
                            <div class="alert alert-danger" role="alert">
                                {{ message }}
                            </div>
                            {% endfor %}
                      {% endif %}
                    {% endwith %}

                    <div class="form-group row">
                        <label class="col-12 col-sm-3 col-form-label text-sm-right">Username</label>
                        <div class="col-8 col-sm-6">
                            <input type="text"  name="username" required="" placeholder="Enter your username" class="form-control">
                        </div>
                    </div>

                    <div class="form-group row">
                        <label class="col-12 col-sm-3 col-form-label text-sm-right">Password</label>
                        <div class="col-8 col-sm-6">
                            <input name="password" type="password" required="" placeholder="Password" class="form-control">
                        </div>
                    </div>

                    <div class="form-group row">
                        <label class="col-12 col-sm-3 col-form-label text-sm-right"></label>
                        <div class="col-8 col-sm-6">
                            <div class="row">
                                <div class="col col-sm-6 col-lg-6 offset-sm-1 offset-lg-0 text-left">
                                    <a href="{{ url_for('reset_password') }}">Forgot password?</a>
                                </div>
                                <div class="col col-sm-6 col-lg-6 offset-sm-1 offset-lg-0 text-right">
                                    <button type="submit" class="btn btn-space btn-primary">Login</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <input type="hidden" id="next_content" name="next_content" value="{{ next_content }}">
                </form>
            </div>
        </div>
    </div>
    <!-- ============================================================== -->
    <!-- end of login form -->
    <!-- ============================================================== -->

</div>

