<table id="templates-table" class="table table-striped table-bordered" style="width:100%">
    <thead>
    <tr>
        <th>id</th>
        <th>title</th>
        <th>status</th>
        <th>portal iuid</th>
        <th>actions</th>
    </tr>
    </thead>
    <tbody>
    {% for t in templates %}
        {% if t['status'] == status %}
        <tr>
            <td>{{ t['id'] }}</td>
            <td><a href="javascript:showTemplateFromId({{ t['id'] }})">{{ t['title'] }}</a></td>
            <td>{{ t.description }}</td>
            <td>{{ t['iuid'] }}</td>
            <td style="width: 105px;">
                <button class="btn btn-sm btn-outline-light" onclick="javascript:showTemplateFromId({{ t['id'] }})"><i class="far fa-edit"></i></button>
                <button class="btn btn-sm btn-outline-light" onclick="javascript:deleteTemplate({{ t['id'] }}, '{{ t['title'] }}')"><i class="far fa-trash-alt"></i></button>
            </td>
        </tr>
        {% endif %}
    {% endfor %}

    </tbody>
</table>