.morris-hover {
    position: absolute;
    z-index: 1000
}

.morris-hover.morris-default-style {
    border-radius: 2px;
    
    color: #3d3f5d;
    background: rgb(255, 255, 255);
    font-size: 14px;
    font-family: 'Circular Std Book';
    text-align: center;
/*    -webkit-box-shadow: 0px 1px 2px 1px rgba(154, 154, 204, 0.22);
    -moz-box-shadow: 0px 1px 2px 1px rgba(154, 154, 204, 0.22);
    box-shadow: 0px 1px 2px 1px rgba(154, 154, 204, 0.22);*/
    border: 1px solid #e6e6f2;

}

.morris-hover.morris-default-style .morris-hover-row-label {
  font-family:'Circular Std Medium';
  border-bottom: 1px solid #e6e6f2;
  padding: 8px;
   
}

.morris-hover.morris-default-style .morris-hover-point {
    white-space: nowrap;
    font-size: 16px;
    padding: 8px;
    background: #f7f7fd;
    line-height: 18px;
      font-family:'Circular Std Medium';
 
}

#morris_donut svg text{
      font-size: 6px!important;
    }

    #morris_donut tspan {
      font-size: 6px!important;
    }