
<div class="alert alert-info" role="alert">
  <h4 class="alert-heading">Acknowledgements</h4>
  <hr>
    <p class="">Users publishing work containing data collected at the Cryo-EM Facility
        should ensure that they acknowledge the relevant facility personnel.
        In addition, the funding agencies should be acknowledged through the following statement:</p>

      <p class="" style="color: #6c757d">“The data was collected at the Cryo-EM Swedish National Facility
          funded by the Knut and Alice Wallenberg, Family Erling Persson and Kempe Foundations, SciLifeLab,
          Stockholm University and Umeå University.”
      </p>
</div>
