<!-- Top Navigation Bar -->
    <div class="dashboard-header">
        <nav class="navbar navbar-expand-lg bg-white fixed-top">
            <img src="{{ url_for('static', filename='images/emhub.png') }}" height="45px" style="margin-left: 15px;">
            <img src="{{ url_for('static', filename='images/emhub-sll.png') }}" height="45px" style="margin-left: 15px;">
{#            <a class="navbar-brand" href="{{ url_for('index') }}">emhub</a>#}
            <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse " id="navbarSupportedContent">
                <ul class="navbar-nav ml-auto navbar-right-top">

                    <li class="nav-item dropdown nav-user">
                        <div class="row">
                            <div class="col-100 ml-0">

                                <!-- Variable content depending if the users is signed in or not -->
                                {% if current_user.is_authenticated %}
                                    <a class="nav-link nav-user-img" href="#" id="navbarDropdownMenuLink2" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                                        {{ current_user.name }} <img src="{{ current_user.image }}" alt="" class="user-avatar-md rounded-circle">
                                    </a>
                                    <div class="dropdown-menu dropdown-menu-right nav-user-dropdown" aria-labelledby="navbarDropdownMenuLink2">
                                        <div class="nav-user-info">
                                            <h5 class="mb-0 text-white nav-user-name">
                                                {{ current_user.name }}</h5>
                                            <span class="status"></span><span class="ml-2">Available</span>
                                        </div>
                                        <a class="dropdown-item" href="javascript:showUser({{ current_user.id }})"><i class="fas fa-user mr-2"></i>Account</a>
    {#                                        <a class="dropdown-item" href="#"><i class="fas fa-cog mr-2"></i>Setting</a>#}
                                        <a class="dropdown-item" href="{{ url_for('do_logout') }}"><i class="fas fa-sign-out-alt mr-2"></i>Logout</a>
                                    </div>
                                {% else %}
                                    <a  class="nav-link nav-user-img" href="{{ url_for('login') }}"><i class="fas fa-sign-in-alt mr-2"></i>Login</a>
                                {% endif %}

                            </div>
                        </div>
                    </li>
                </ul>
            </div>
        </nav>
    </div>
    <!-- end of Top Navigation Bar -->