

<div class="row col-12 p-0">
    {% for slot in range(1, 13) %}

        <div class="col-4 pr-0">
            <div class="card">
                <div class="card-header p-1 ml-2">
                    <h5 class="m-0 p-0">Slot {{ slot }} </h5>
                </div>
                <div class="card-body">


                </div>

            </div>
        </div>

    {% endfor %}
</div>

