
<div class="container-fluid dashboard-content">
    <!-- Header -->
    {% set title = "Transactions List" %}
    {% set navigation = [('Admin', ''), ('Transactions', '')] %}
    {% include 'include_header.html' %}

    {% include 'transactions_list.html' %}

</div>

