<p>Dear {{ user.name }},</p>
<p>
    To reset your password
    <a href="{{ url_for('do_reset_password', token=token, _external=True) }}">
        click here
    </a>.
</p>
<p>Alternatively, you can paste the following link in your browser's address bar:</p>
<p>{{ url_for('do_reset_password', token=token, _external=True) }}</p>
<p>If you have not requested a password reset simply ignore this message.</p>
<p>Sincerely,</p>
<p>The CryoEM Facility Staff</p>