
<div class="container-fluid  dashboard-content">
    <!-- Header -->
    {% include 'include_header.html' %}

<div class="col-xl-12 col-lg-12 col-md-12 col-sm-12 col-12">
<div class="card">
<div class="card-body page-content">

{% filter markdown %}

{% include page %}

{% endfilter %}

</div>
</div>
</div>


</div>

