
{% for users in labs %}

    <div class="col-xl-4 col-lg-4 col-md-6 col-sm-12 col-12 mb-4">
        <div class="card h-100">
            <div class="card-header">
                <h3>{{ users[0]['name'] }}</h3>

            </div>
            <div class="card-body">
                <ul>
                    {% for user in users[1:] %}
                        <li><a href="javascript:showUser({{ user.id }})">{{ user['name'] }}</a></li>
                    {% endfor %}
                </ul>
            </div>


        </div>
    </div>
{% endfor %}


